@@ -34,10 +34,14 @@
 (defun init-mule-tty-win ()
   "Initialize TTY for MULE at startup. Don't call this."
   (unless mule-tty-win-initted
-    (add-hook 'after-init-hook
-	      (lambda ()
-		(set-console-tty-coding-system
-		 (selected-console) terminal-coding-system)))
+    (add-hook
+     'after-init-hook
+     (lambda ()
+       (when (eq (device-type) 'tty)
+	 (when (string-match "^kterm" (getenv "TERM"))
+	   (set-terminal-coding-system 'iso-2022-jp)
+	   (set-keyboard-coding-system 'iso-2022-jp))
+	 (set-console-tty-coding-system))))
     (setq mule-tty-win-initted t)))
 
 ;;; mule-tty-init.el ends here
